
  - For a list of bug fixes, see
    https://github.com/radical-cybertools/radical.repex/ \
            issues?q=is%3Aissue+is%3Aclosed+sort%3Aupdated-desc
  - For a list of open issues and known problems, see
    https://github.com/radical-cybertools/radical.repex/ \
            issues?q=is%3Aissue+is%3Aopen+


v0.70.0 Release                                                       2019-07-07
--------------------------------------------------------------------------------

  -  move sliding windo alg here
  -  add workload description in json
  -  fix exchange list verification


Version 0.0.1 release                                                 2014-10-31
--------------------------------------------------------------------------------

  -  initial commit for radical project 'repex'


--------------------------------------------------------------------------------

